@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 """
 setup.py for installing F2PY
 
@@ -16,8 +16,6 @@ $Date: 2005/01/30 17:22:14 $
 Pearu Peterson
 
 """
-from __future__ import division, print_function
-
 from numpy.distutils.core import setup
 from numpy.distutils.misc_util import Configuration
 
@@ -27,10 +25,15 @@ from __version__ import version
 
 def configuration(parent_package='', top_path=None):
     config = Configuration('f2py', parent_package, top_path)
-    config.add_data_dir('tests')
+    config.add_subpackage('tests')
+    config.add_subpackage('_backends')
+    config.add_data_dir('tests/src')
     config.add_data_files(
         'src/fortranobject.c',
-        'src/fortranobject.h')
+        'src/fortranobject.h',
+        'backends/meson.build.template',
+    )
+    config.add_data_files('*.pyi')
     return config
 
 
@@ -39,8 +42,6 @@ if __name__ == "__main__":
     config = configuration(top_path='')
     config = config.todict()
 
-    config['download_url'] = "http://cens.ioc.ee/projects/f2py2e/2.x"\
-                             "/F2PY-2-latest.tar.gz"
     config['classifiers'] = [
         'Development Status :: 5 - Production/Stable',
         'Intended Audience :: Developers',
@@ -68,6 +69,6 @@ command line tool (f2py) for generating Python C/API modules for
 wrapping Fortran 77/90/95 subroutines, accessing common blocks from
 Python, and calling Python functions from Fortran (call-backs).
 Interfacing subroutines/data from Fortran 90/95 modules is supported.""",
-          url="http://cens.ioc.ee/projects/f2py2e/",
+          url="https://numpy.org/doc/stable/f2py/",
           keywords=['Fortran', 'f2py'],
           **config)
