@@ -14,9 +14,10 @@ from urllib.request import urlopen, Request
 from urllib.error import HTTPError
 
 OPENBLAS_V = '0.3.23.dev'
-OPENBLAS_LONG = 'v0.3.23-246-g3d31191b'
-BASE_LOC = 'https://anaconda.org/multibuild-wheels-staging/openblas-libs'
-BASEURL = f'{BASE_LOC}/{OPENBLAS_LONG}/download'
+OPENBLAS_LONG = 'v0.3.23-293-gc2f4bdbb'
+BASE_LOC = (
+    'https://anaconda.org/scientific-python-nightly-wheels/openblas-libs'
+)
 SUPPORTED_PLATFORMS = [
     'linux-aarch64',
     'linux-x86_64',
@@ -91,7 +92,7 @@ def get_linux(arch):
         return get_musllinux(arch)
 
 
-def download_openblas(target, plat, ilp64):
+def download_openblas(target, plat, ilp64, *, nightly=False):
     osname, arch = plat.split("-")
     fnsuffix = {None: "", "64_": "64_"}[ilp64]
     filename = ''
@@ -120,7 +121,12 @@ def download_openblas(target, plat, ilp64):
 
     if not suffix:
         return None
-    filename = f'{BASEURL}/openblas{fnsuffix}-{OPENBLAS_LONG}-{suffix}'
+    openblas_version = "HEAD" if nightly else OPENBLAS_LONG
+    filename = (
+        f'{BASE_LOC}/{openblas_version}/download/'
+        f'openblas{fnsuffix}-{openblas_version}-{suffix}'
+    )
+    print(f'Attempting to download {filename}', file=sys.stderr)
     req = Request(url=filename, headers=headers)
     try:
         response = urlopen(req)
@@ -141,7 +147,7 @@ def download_openblas(target, plat, ilp64):
     return typ
 
 
-def setup_openblas(plat=get_plat(), ilp64=get_ilp64()):
+def setup_openblas(plat=get_plat(), ilp64=get_ilp64(), nightly=False):
     '''
     Download and setup an openblas library for building. If successful,
     the configuration script will find it automatically.
@@ -155,7 +161,7 @@ def setup_openblas(plat=get_plat(), ilp64=get_ilp64()):
     _, tmp = mkstemp()
     if not plat:
         raise ValueError('unknown platform')
-    typ = download_openblas(tmp, plat, ilp64)
+    typ = download_openblas(tmp, plat, ilp64, nightly=nightly)
     if not typ:
         return ''
     osname, arch = plat.split("-")
@@ -182,10 +188,11 @@ def unpack_windows_zip(fname, plat):
     # Copy the lib to openblas.lib. Once we can properly use pkg-config
     # this will not be needed
     lib = glob.glob(os.path.join(target, 'lib', '*.lib'))
-    assert len(lib) == 1
-    for f in lib:
-        shutil.copy(f, os.path.join(target, 'lib', 'openblas.lib'))
-        shutil.copy(f, os.path.join(target, 'lib', 'openblas64_.lib'))
+    if len(lib) == 1:
+        # The 64-bit tarball already has these copied, no need to do it
+        for f in lib:
+            shutil.copy(f, os.path.join(target, 'lib', 'openblas.lib'))
+            shutil.copy(f, os.path.join(target, 'lib', 'openblas64_.lib'))
     # Copy the dll from bin to lib so system_info can pick it up
     dll = glob.glob(os.path.join(target, 'bin', '*.dll'))
     for f in dll:
@@ -322,6 +329,9 @@ def test_version(expected_version=None):
 
     data = threadpoolctl.threadpool_info()
     if len(data) != 1:
+        if platform.python_implementation() == 'PyPy':
+            print(f"Not using OpenBLAS for PyPy in Azure CI, so skip this")
+            return
         raise ValueError(f"expected single threadpool_info result, got {data}")
     if not expected_version:
         expected_version = OPENBLAS_V
@@ -342,11 +352,13 @@ if __name__ == '__main__':
     parser.add_argument('--check_version', nargs='?', default='',
                         help='Check provided OpenBLAS version string '
                              'against available OpenBLAS')
+    parser.add_argument('--nightly', action='store_true',
+                        help='If set, use nightly OpenBLAS build.')
     args = parser.parse_args()
     if args.check_version != '':
         test_version(args.check_version)
     elif args.test is None:
-        print(setup_openblas())
+        print(setup_openblas(nightly=args.nightly))
     else:
         if len(args.test) == 0 or 'all' in args.test:
             test_setup(SUPPORTED_PLATFORMS)
